ps.plone.basepolicy
===================

Basic Site Policy for `Propertyshelf`_ Plone Websites.


Installed Add-Ons
-----------------

The following Add-Ons will be installed automatically:

- `Products.PloneFormGen`_
- `collective.contentleadimage`_
- `plone.app.theming`_


Custom Settings
---------------

When installed, some Plone settings will be adjusted, like:

- SMTP server and port
- Site 'From' name and address
- Generate tabs for items other than folders
- Enable sitemap.xml.gz
- Enable Dublin Core metadata
- Open external links in new window
- Don't use email address as login name


Mostly Harmless
---------------

.. image:: https://travis-ci.org/propertyshelf/ps.plone.basepolicy.png?branch=master
   :target: http://travis-ci.org/propertyshelf/ps.plone.basepolicy

.. _`Products.PloneFormGen`: https://pypi.python.org/pypi/Products.PloneFormGen
.. _`Propertyshelf`: http://propertyshelf.com
.. _`collective.contentleadimage`: https://pypi.python.org/pypi/collective.contentleadimage
.. _`plone.app.theming`: https://pypi.python.org/pypi/plone.app.theming
